==> eiffelstudio-18.07.10.1981.tar: F_code/C8/sh382.c <==
/*
 * Code for class SHARED_ENCODING_CONVERTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sh382.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SHARED_ENCODING_CONVERTER}.encoding_converter */
EIF_REFERENCE F673_6949 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("encoding_converter", 672, Current, 1, 0, 7413);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(6952,F673_6952,(Current))));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc1;
	} else {
		RTHOOK(4);
		tr1 = RTLNS(eif_new_type(1525, 0x00).id, 1525, _OBJSIZ_4_2_0_0_0_0_0_0_);
		F1526_17716(RTCW(tr1));
		Result = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		F673_6951(Current, Result);
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {SHARED_ENCODING_CONVERTER}.set_encoding_converter */
void F673_6951 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("set_encoding_converter", 672, Current, 0, 1, 7415);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6952,F673_6952,(Current));
	F194_2944(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {SHARED_ENCODING_CONVERTER}.encoding_converter_cell */
static EIF_REFERENCE F673_6952_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("encoding_converter_cell", 672, Current, 0, 0, 7416);
	RTGC;
	RTOSP (6952);
#define Result RTOSR(6952)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {193,1525,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 193, _OBJSIZ_1_0_0_0_0_0_0_0_);
	}
	F194_2944(RTCW(tr1), NULL);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (6952);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F673_6952 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6952,F673_6952_body,(Current));
}

void EIF_Minit382 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C8/sh382.c <==
/*
 * Code for class SHARED_ENCODING_CONVERTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "sh382.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SHARED_ENCODING_CONVERTER}.encoding_converter */
EIF_REFERENCE F448_6697 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("encoding_converter", 447, Current, 1, 0, 6652);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(6700,F448_6700, (Current))));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(2);
		RTHOOK(3);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) loc1;
	} else {
		RTHOOK(4);
		Result = RTLNS(eif_new_type(1534, 0x00).id, 1534, _OBJSIZ_4_2_0_0_0_0_0_0_);
		F1535_17999(RTCW(Result));
		RTHOOK(5);
		F448_6699(Current, Result);
	}
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
}

/* {SHARED_ENCODING_CONVERTER}.set_encoding_converter */
void F448_6699 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("set_encoding_converter", 447, Current, 0, 1, 6654);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6700,F448_6700, (Current));
	F190_2809(RTCW(tr1), arg1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {SHARED_ENCODING_CONVERTER}.encoding_converter_cell */
static EIF_REFERENCE F448_6700_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("encoding_converter_cell", 447, Current, 0, 0, 6655);
	RTGC;
	RTOSP (6700);
#define Result RTOSR(6700)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {189,1534,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 189, _OBJSIZ_1_0_0_0_0_0_0_0_);
	}
	F190_2809(RTCW(tr1), NULL);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (6700);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F448_6700 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6700,F448_6700_body,(Current));
}

void EIF_Minit382 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
